@@ -2,7 +2,7 @@
 #include "screenadaptor.h"
 #include <QDBusInterface>
 
-#include "code/settingsstore.h"
+#include "settingsstore.h"
 
 #include <QDebug>
 
