@@ -2,7 +2,7 @@
 #include "themeadaptor.h"
 #include <QDBusInterface>
 
-#include "code/settingsstore.h"
+#include "settingsstore.h"
 
 #include <QDebug>
 
@@ -26,6 +26,9 @@ Theme::Theme(QObject *parent) : QObject(parent)
     m_enableCSD = settings.load("EnableCSD", m_enableCSD).toBool();
     m_borderRadius = settings.load("BorderRadius", m_borderRadius).toUInt();
     m_iconSize = settings.load("IconSize", m_iconSize).toUInt(&ok);
+    m_paddingSize = settings.load("PaddingSize", m_paddingSize).toUInt(&ok);
+    m_marginSize = settings.load("MarginSize", m_marginSize).toUInt(&ok);
+    m_spacingSize = settings.load("SpacingSize", m_spacingSize).toUInt(&ok);
     m_enableEffects = settings.load("EnableEffects", m_enableEffects).toBool();
     settings.endModule();
 }
@@ -50,8 +53,6 @@ const QString &Theme::accentColor() const
 
 void Theme::setAccentColor(const QString &newAccentColor)
 {
-    qDebug() << "SET ACCENT COLOR" << this->connection().baseService() << this->message().path() << this->message().member();
-
     if (m_accentColor == newAccentColor)
         return;
     m_accentColor = newAccentColor;
@@ -137,3 +138,45 @@ void Theme::setEnableEffects(bool enableEffects)
     m_enableEffects = enableEffects;
     Q_EMIT enableEffectsChanged(m_enableEffects);
 }
+
+uint Theme::paddingSize() const
+{
+    return m_paddingSize;
+}
+
+uint Theme::marginSize() const
+{
+    return m_marginSize;
+}
+
+uint Theme::spacingSize() const
+{
+    return m_spacingSize;
+}
+
+void Theme::setSpacingSize(uint spacingSize)
+{
+    if (m_spacingSize == spacingSize)
+        return;
+
+    m_spacingSize = spacingSize;
+    emit spacingSizeChanged(m_spacingSize);
+}
+
+void Theme::setPaddingSize(uint paddingSize)
+{
+    if (m_paddingSize == paddingSize)
+        return;
+
+    m_paddingSize = paddingSize;
+    Q_EMIT paddingSizeChanged(m_paddingSize);
+}
+
+void Theme::setMarginSize(uint marginSize)
+{
+    if (m_marginSize == marginSize)
+        return;
+
+    m_marginSize = marginSize;
+    Q_EMIT marginSizeChanged(m_marginSize);
+}
