@@ -2,12 +2,10 @@
 
 #include <QObject>
 #include <QString>
-#include <QDBusContext>
 
-#include "code/modules/thememanager.h"
+#include "modules/thememanager.h"
 
 class Theme : public QObject
-        , protected QDBusContext
 {
     Q_OBJECT
     Q_PROPERTY(int styleType READ styleType WRITE setStyleType NOTIFY styleTypeChanged)
@@ -17,6 +15,9 @@ class Theme : public QObject
     Q_PROPERTY(bool enableCSD READ enableCSD WRITE setEnableCSD NOTIFY enableCSDChanged)
     Q_PROPERTY(uint borderRadius READ borderRadius WRITE setBorderRadius NOTIFY borderRadiusChanged)
     Q_PROPERTY(uint iconSize READ iconSize WRITE setIconSize NOTIFY iconSizeChanged)
+    Q_PROPERTY(uint paddingSize READ paddingSize WRITE setPaddingSize NOTIFY paddingSizeChanged)
+    Q_PROPERTY(uint marginSize READ marginSize WRITE setMarginSize NOTIFY marginSizeChanged)
+    Q_PROPERTY(uint spacingSize READ spacingSize WRITE setSpacingSize NOTIFY spacingSizeChanged)
     Q_PROPERTY(bool enableEffects READ enableEffects WRITE setEnableEffects NOTIFY enableEffectsChanged)
 
 public:
@@ -46,6 +47,15 @@ public:
     bool enableEffects() const;
     void setEnableEffects(bool enableEffects);
 
+    void setPaddingSize(uint paddingSize);
+    uint paddingSize() const;
+
+    void setMarginSize(uint marginSize);
+    uint marginSize() const;
+
+    uint spacingSize() const;
+    void setSpacingSize(uint spacingSize);
+
 signals:
     void styleTypeChanged(int styleStype);
     void accentColorChanged(QString accentColor);
@@ -62,6 +72,12 @@ signals:
 
     void enableEffectsChanged(bool enableEffects);
 
+    void paddingSizeChanged(uint paddingSize);
+
+    void marginSizeChanged(uint marginSize);
+
+    void spacingSizeChanged(uint spacingSize);
+
 private:
     int m_styleType = MauiMan::ThemeManager::DefaultValues::styleType;
     QString m_accentColor = MauiMan::ThemeManager::DefaultValues::accentColor;
@@ -71,4 +87,7 @@ private:
     uint m_borderRadius = MauiMan::ThemeManager::DefaultValues::borderRadius;
     uint m_iconSize = MauiMan::ThemeManager::DefaultValues::iconSize;
     bool m_enableEffects = MauiMan::ThemeManager::DefaultValues::enableEffects;
+    uint m_paddingSize = MauiMan::ThemeManager::DefaultValues::paddingSize;
+    uint m_marginSize = MauiMan::ThemeManager::DefaultValues::marginSize;
+    uint m_spacingSize = MauiMan::ThemeManager::DefaultValues::spacingSize;
 };
