@@ -2,9 +2,28 @@
 #include <QDBusConnectionInterface>
 #include <QDebug>
 
-#include "src/modules/background.h"
-#include "src/modules/theme.h"
-#include "src/modules/screen.h"
+#include "modules/background.h"
+#include "modules/theme.h"
+#include "modules/screen.h"
+#include "modules/formfactor.h"
+#include "modules/accessibility.h"
+
+#include <signal.h>
+
+void sigtermHandler(int signalNumber)
+{
+    qDebug() << "terminating cask session" << signalNumber;
+    if (QCoreApplication::instance()) {
+        QCoreApplication::instance()->exit(-1);
+        qDebug() << "terminating caks session FINISHED" << signalNumber;
+
+    }
+}
+
+void sigHandler(int signalNumber)
+{
+    qDebug() << "terminating MauiManServer session" << signalNumber;
+}
 
 Server::Server(int &argc, char **argv) : QCoreApplication(argc, argv)
 {
@@ -38,10 +57,15 @@ bool Server::init()
                  qPrintable(registration.error().message()));
 
         return false;
-    }
+    }    
 
-    m_modules << new Background(this);
-    m_modules << new Theme(this);
-    m_modules << new Screen(this);
+    signal(SIGTERM, sigtermHandler);
+    signal(SIGINT, sigHandler);
+
+    m_modules << new Background();
+    m_modules << new Theme();
+    m_modules << new Screen();
+    m_modules << new FormFactor();
+    m_modules << new Accessibility();
     return true;
 }
